@@ -134,22 +134,23 @@ around run => sub ( $orig, $self, $req ) {
     my $api_map = {
 
         # type            => 'remoting',
-        type         => 'websocket',
-        id           => 'api',
-        url          => $self->{app}->{router}->get_host_api_path( $req->{host} ),
-        namespace    => 'API.' . ref( $self->{app} ) =~ s[::][]smgr,
-        actions      => $ext_app->{api},
-        timeout      => undef,
-        version      => undef,
-        maxRetries   => 0,                                                           # number of times to re-attempt delivery on failure of a call
-        headers      => undef,
-        enableBuffer => \0,                                                          # true or false to enable or disable combining of method calls. If a number is specified this is the amount of time in milliseconds to wait before sending a batched request
+        type    => 'websocket',
+        url     => $self->{app}->{router}->get_host_api_path( $req->{host} ),
+        actions => $ext_app->{api},
 
-        # enableUrlEncode => 'data',
+        # not mandatory options
+        id              => 'api',
+        namespace       => 'API.' . ref( $self->{app} ) =~ s[::][]smgr,
+        timeout         => 0,                                             # milliseconds, 0 - no timeout
+        version         => undef,
+        maxRetries      => 0,                                             # number of times to re-attempt delivery on failure of a call
+        headers         => {},
+        enableBuffer    => 10,                                            # \1, \0, milliseconds
+        enableUrlEncode => undef,
     };
 
     my $data = {
-        INDEX => {                                                                   #
+        INDEX => {                                                        #
             title => $self->ext_app_title
         },
         resources => $resources,
